@@ -10,7 +10,7 @@ def time_block(statsd_client):
         end = time.time()
 
         delta_in_ms = int((end - start) * 1000)
-        statsd_client.timing("job_time", delta_in_ms)
+        statsd_client.timing('job_time', delta_in_ms)
     else:
         # Do nothing here.
         yield
@@ -19,10 +19,10 @@ def time_block(statsd_client):
 def mark_successful_job(statsd_client):
     if not statsd_client:
         return
-    statsd_client.incr("success")
+    statsd_client.incr('success')
 
 
 def mark_failed_job(statsd_client):
     if not statsd_client:
         return
-    statsd_client.incr("failure")
+    statsd_client.incr('failure')
